@@ -6,9 +6,7 @@ use warnings;
 use Perl::Critic::Utils qw(:severities :classification :ppi);
 use parent 'Perl::Critic::Policy';
 
-use List::Util 'any';
-
-our $VERSION = '0.025';
+our $VERSION = '0.026';
 
 use constant DESC => 'Using function prototypes';
 use constant EXPL => 'Function prototypes (sub foo ($@) { ... }) will usually not do what you want. Omit the prototype, or use signatures instead.';
@@ -23,7 +21,13 @@ sub violates {
 	
 	# Check if signatures are enabled
 	my $includes = $elem->find('PPI::Statement::Include') || [];
-	return () if any { $_->pragma eq 'feature' and m/\bsignatures\b/ } @$includes;
+	foreach my $include (@$includes) {
+	  next unless $include->type eq 'use';
+	  return () if $include->pragma eq 'feature' and $include =~ m/\bsignatures\b/;
+	  return () if $include->pragma eq 'experimental' and $include =~ m/\bsignatures\b/;
+	  return () if $include->module eq 'Mojo::Base' and $include =~ m/-signatures\b/;
+	  return () if $include->module eq 'Mojolicious::Lite' and $include =~ m/-signatures\b/;
+	}
 	
 	my $prototypes = $elem->find('PPI::Token::Prototype') || [];
 	my @violations;
@@ -52,7 +56,8 @@ modern method of declaring arguments.
 
   sub foo ($$) { ... } # not ok
   sub foo { ... }      # ok
-  use feature 'signatures'; sub foo ($bar, $baz) { ... } # ok
+  use feature 'signatures'; sub foo ($bar, $baz) { ... }      # ok
+  use experimental 'signatures'; sub foo ($bar, $baz) { ... } # ok
 
 This policy is similar to the core policy
 L<Perl::Critic::Policy::Subroutines::ProhibitSubroutinePrototypes>, but
